<?php
/*
Plugin Name: Member Lock
Plugin URI: http://nanacast.com/docs/member-lock.html
Description: WP members-only access integrated with Nanacast.com
Version: 1.6
Author: Nanacast.com
Author URI: http://nanacast.com/

*/


/*  
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
		
	You may also view the license here:
	http://www.gnu.org/licenses/gpl.html#SEC1
*/


/*
INSTALLATION PROCEDURE:
	
	* Upload the entire memberlock directory to your plugins directory
	* Login to the WP admin
	* Go to plugins tab and activate the plugin
	
	For more complete installation and usage instructions,
	visit http://nanacast.com/docs/member-lock.html

*/


add_action('init', 'memberlock');  // runs the memberlock() function right away, allows for setting cookies
add_action('widgets_init', 'widget_memberlockwidget_init');  // if you are using widgets, this initializes the widget

// note: feed-rss.php uses the_content_rss and feed-rss2.php uses the_content.  
// so don't assume that the_content_rss is used for every RSS feed.
add_filter('the_content', 'memberlock_securify', $content, $priority=1);  // runs the memberlock_securify on the $content.
add_filter('the_content_rss', 'memberlock_securify', $content, $priority=1);  // runs the memberlock_securify on the $content for some RSS feeds.
add_filter('rss_enclosure', 'memberlock_securify_enclosure', $content, $priority=1);  // runs the memberlock_securify on the enclosure for RSS feeds.

add_action('admin_menu', 'memberlock_config_page'); // adds configuration option to the admin menu
add_action('wp_login', 'memberlock_wp_login'); // makes sure you aren't suspended

add_filter('the_posts', 'memberlock_append_remote_feed', $pages, $priority=10);  // appends a remote feed onto your posts on the main page
add_filter('the_permalink', 'memberlock_the_permalink', $link, $priority=10);  // makes the permalink for a remote post go to the remote page in new window.
add_filter('the_permalink_rss', 'memberlock_the_permalink_rss', $link, $priority=10);  // makes the permalink for a remote post go to the remote page
add_action('rss2_item', 'memberlock_rss2_item', $content, $priority=10);  // adds enclosures for remote posts.

function memberlock_rss2_item ($content) {
	global $post;
	print $post->memberlock_enclosure;
}
function memberlock_the_permalink ($permalink) {
	global $post;
	if (!$permalink) $permalink = $post->memberlock_permalink;
	return $permalink;
}
function memberlock_the_permalink_rss ($permalink) {
	global $post;
	if (!$permalink) $permalink = $post->memberlock_permalink_rss;
	return $permalink;
}
function get_feed_array ($url) {
    global $db;
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL,$url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER,1);
    $result = curl_exec ($ch);
    curl_close ($ch); 
   	$data = memberlock_GetXMLTree($result);
    return $data;
}
function memberlock_trim_excerpt ($text) {
	global $summary_length;
	// derived from wp_trim_excerpt()
	if (!$summary_length) {
		$summary_length = get_option('memberlock_summary_length');
		$summary_length = ($summary_length) ? $summary_length : 55;
	}
	$text = strip_tags($text);
	$words = explode(' ', $text, $summary_length);
	if (count($words) > $summary_length -1) {
		array_pop($words); // get rid of rest of string
		array_push($words, '[...]');
		$text = implode(' ', $words);
	}
	return $text;
}
function memberlock_append_remote_feed ($pages) {
	global $user_login;
	$append_remote_feed = get_option('memberlock_append_remote_feed');
	$show_complete_on_homepage = get_option('memberlock_show_complete_on_homepage');
	$show_summary_on_rss = get_option('memberlock_show_summary_on_rss');
	if ($append_remote_feed && !is_single() && !is_page() && is_user_logged_in()) {
		$user = new WP_User(0, $user_login);
		if ($user->ID) {
			$feedurl = get_usermeta($user->ID, 'memberlock_feedurl')."?ip=".$_SERVER['REMOTE_ADDR'];
			if ($feedurl != '') {
				$feed_data = get_feed_array ($feedurl); 
				$items = $feed_data['RSS'][0]['CHANNEL'][0]['ITEM'];
				if (is_array($items) && count($items)) {
					foreach ($items as $item) {
						$post_date = date('Y-m-d H:i:s',strtotime($item['PUBDATE'][0]['VALUE']));
						$post = array(
				            'ID' => '0',
				            'post_author' => 1,
				            'post_date' => $post_date,
				            'post_date_gmt' => $post_date,
				            'post_content' => ($show_complete_on_homepage) ? $item['DESCRIPTION'][0]['VALUE'] : memberlock_trim_excerpt($item['DESCRIPTION'][0]['VALUE']),
				            'post_title' => $item['TITLE'][0]['VALUE'],
				            'post_category' => 0,
				            'post_excerpt' => ($show_summary_on_rss) ? memberlock_trim_excerpt($item['DESCRIPTION'][0]['VALUE']) : $item['DESCRIPTION'][0]['VALUE'], // rss
				            'post_status' => 'publish',
				            'comment_status' => 'closed',
				            'ping_status' => 'closed',
				            'post_password' => '',
				            'post_name' => $item['TITLE'][0]['VALUE'],
				            'to_ping' => '',
				            'pinged' => '',
				            'post_modified' => $post_date,
				            'post_modified_gmt' => $post_date,
				            'post_content_filtered' => ($show_complete_on_homepage) ? $item['DESCRIPTION'][0]['VALUE'] : memberlock_trim_excerpt($item['DESCRIPTION'][0]['VALUE']),
				            'post_parent' => 0,
				            'guid' => htmlentities($item['LINK'][0]['VALUE']),
				            'menu_order' => 0,
				            'post_type' => 'post',
				            'post_mime_type' => '',
				            'comment_count' => '0',
							//'filter' => 'sample',
							'memberlock_permalink'	=> $item['LINK'][0]['VALUE'].'" target="_blank',
							'memberlock_permalink_rss'	=> htmlentities($item['LINK'][0]['VALUE']),
							'memberlock_enclosure' => (isset($item['ENCLOSURE'])) 
								? '<enclosure url="'.$item['ENCLOSURE'][0]['ATTRIBUTES']['URL'].'" length="'.$item['ENCLOSURE'][0]['ATTRIBUTES']['LENGTH'].'" '.
									'type="'.$item['ENCLOSURE'][0]['ATTRIBUTES']['TYPE'].'" />' : '',
			        	);
						$pages[] = (object)$post;
					}
					// sort posts by date
					$temp_pages = array();
					for($i=0;$i<count($pages);$i++) {
						$key = preg_replace("/-:/",'',$pages[$i]->post_date);
						// keep posts in the order they originally appear in if the share the same date
						// otherwise posts with the same date will overwrite each other with their key
						$key = $key.str_pad($i, 4, "0", STR_PAD_LEFT); // we just append the order it is in the array 0001,0002..0999, etc...
						$temp_pages[$key] = $pages[$i];
					}
					krsort($temp_pages);
					$pages = array();
					foreach($temp_pages as $temp_page) {
						$pages[] = $temp_page;
					}
				}
			}
		}
	}
	return $pages;
}

if ( !get_option('memberlock_sales_html') && !$memberlock_sales_html && !isset($_POST['submit']) ) {
	function memberlock_warning() {
		echo "
		<div id='memberlock-warning' class='updated fade'><p><strong>".__('Member Lock is almost ready.')."</strong> ".sprintf(__('You must <a href="%1$s">add a few settings</a> for it to work.'), "plugins.php?page=memberlock")."</p></div>
		";
	}
	add_action('admin_notices', 'memberlock_warning');
	return;
}
function memberlock_config_page() {
	if ( function_exists('add_submenu_page') )
		add_submenu_page('plugins.php', __('Member Lock Settings'), __('Member Lock Settings'), 'manage_options', 'memberlock', 'memberlock_conf');

}

function memberlock_conf() {
	global $memberlock_nonce, $memberlock_sales_html;

	if ( isset($_POST['submit']) ) {
		if ( function_exists('current_user_can') && !current_user_can('manage_options') )
			die(__('Cheatin&#8217; uh?'));

		$memberlock_sales_html = $_POST['memberlock_sales_html'];
		$memberlock_sales_html = stripslashes($memberlock_sales_html);
		
		update_option('memberlock_sales_html', $memberlock_sales_html);
		update_option('memberlock_billing_link', stripslashes($_POST['memberlock_billing_link']));
		update_option('memberlock_security_code',stripslashes($_POST['memberlock_security_code']));
		update_option('memberlock_append_remote_feed',(int)$_POST['memberlock_append_remote_feed']);
		update_option('memberlock_show_complete_on_homepage',(int)$_POST['memberlock_show_complete_on_homepage']);
		update_option('memberlock_show_summary_on_rss',(int)$_POST['memberlock_show_summary_on_rss']);
		update_option('memberlock_summary_length',(int)$_POST['memberlock_summary_length']);
	}
	$memberlock_sales_html = get_option('memberlock_sales_html');

?>
<?php if ( !empty($_POST ) ) : ?>
<div id="message" class="updated fade"><p><strong><?php _e('Options saved.') ?></strong></p></div>
<?php endif; ?>

<div class="wrap">
<h2><?php _e('Member Lock Settings'); ?></h2>
<div class="narrow">
<form action="" method="post" id="memberlock-conf" name="memberlock_conf_form" style="margin: auto; width: 400px; ">
<?php _e('<a target=_blank href="http://nanacast.com/docs/member-lock.html">Configure Registration System</a>'); ?>
<h3><label for="memberlock_sales_html"><?php _e('Sales Page/Login Form HTML'); ?> (required)</label></h3>
This is the HTML that goes right above the login form when non-logged-in visitors try to view a protected post.
<p><textarea id="memberlock_sales_html" style="font-family: 'Courier New', Courier, mono; font-size: 1.5em;" 
	rows="6" cols="80" name="memberlock_sales_html"  onfocus="this.select();"><?php print $memberlock_sales_html; ?></textarea>
	<a href="#" onclick="return populate_sales_html();">Click here to reset to default template</a>
<script>
function populate_sales_html () {
	document.memberlock_conf_form.memberlock_sales_html.value = 
		"Sorry, this content is available for members only.<br><a href='ENTER_YOUR_SALES_PAGE_URL_HERE'>Click here to join now!</a>";
	return false;
}
<?php if ($memberlock_sales_html == '') { ?>
	populate_sales_html ();
<?php } ?>
</script>
<h3><label for="memberlock_billing_link"><?php _e('Membership Billing Info URL'); ?> (optional)</label></h3> 
This is the URL to your custom membership login page hosted on Nanacast.com.
	<p><input id="memberlock_billing_link" name="memberlock_billing_link" type="text" size="20"  value="<?php echo get_option('memberlock_billing_link'); ?>" style="font-family: 'Courier New', Courier, mono; font-size: 1.5em;" /> 
		(<?php _e('<a target=_blank href="http://nanacast.com/docs/member-lock.html">What is this?</a>'); ?>)</p>


<h3><label for="security_code"><?php _e('Security Code'); ?></label> (optional)</h3> 
This is a random security code you make up.  You will add this security code to the end of your Remote API URL you enter for your membership in Nanacast.com.
	<p><input id="memberlock_security_code" name="memberlock_security_code" type="text" size="20"  value="<?php echo get_option('memberlock_security_code'); ?>" style="font-family: 'Courier New', Courier, mono; font-size: 1.5em;" /> 
		(<?php _e('<a target=_blank href="http://nanacast.com/docs/member-lock.html">What is this?</a>'); ?>)</p>

<h3><label for="drip_content"><?php _e('Display Membership Content Hosted On Nanacast.com'); ?></label></h3> 
Members must be logged in to view this content.  
This is useful if you want to have the posts appear in a "dripped" fashion based on the date the member joined.
	<p>Display Membership Content: <input id="memberlock_append_remote_feed" name="memberlock_append_remote_feed" type="checkbox" value="1" 
			<?php if (get_option('memberlock_append_remote_feed')): ?>CHECKED<?php endif; ?> style="font-family: 'Courier New', Courier, mono; font-size: 1.5em;" /> 
	<br>Show Entire Post Instead of Summary On Main Page: <input id="memberlock_show_complete_on_homepage" name="memberlock_show_complete_on_homepage" type="checkbox" value="1" 
			<?php if (get_option('memberlock_show_complete_on_homepage')): ?>CHECKED<?php endif; ?> style="font-family: 'Courier New', Courier, mono; font-size: 1.5em;" /> 
	<br>Show Summary Instead of Entire Post In RSS Feed: <input id="memberlock_show_summary_on_rss" name="memberlock_show_summary_on_rss" type="checkbox" value="1" 
			<?php if (get_option('memberlock_show_summary_on_rss')): ?>CHECKED<?php endif; ?> style="font-family: 'Courier New', Courier, mono; font-size: 1.5em;" /> 
	<br>Summary Length: <input id="memberlock_summary_length" name="memberlock_summary_length" type="text" size="5"  
		value="<?php echo get_option('memberlock_summary_length'); ?>" style="font-family: 'Courier New', Courier, mono; font-size: 1.5em;" /> words &nbsp;&nbsp;(default is 55 words)
				
	</p>


	<p class="submit"><input type="submit" name="submit" value="<?php _e('Update Options &raquo;'); ?>" /></p>
</form>
</div>
</div>
<?php
}

function memberlock() {
	global $memberlock_a;
	$memberlock_a = trim($_REQUEST['a']);
	switch ($memberlock_a) {
		case ("login"):
			memberlock_login();
			break;
		case ("logout"):
			memberlock_logout();
			break;
	} // end of switch $a (action)
}

function memberlock_securify ($content) {
	global $memberlock_regchk, $memberlock_themsg, $memberlock_a, $post, $more;
	//print_r($post);

	// when rss_use_excerpt == 1, wp_trim_excerpt() is called, which does a strip_tags() on the content 
	// and grabs the first 55 words if there is no excerpt saved already
	// it then runs the content through memberlock_securify()
	
	// if rss_use_excerpt == 0, then the full text is shown.

	if (preg_match('/<!--more(-memberlock(.*))-->/', $post->post_content,$matches)) {
		$post_is_private = true;
		//print_r($matches);
		
		// $content is processed in function get_the_content()
		// global $more == 1 on rss feed pages, and the single post page.  $more == 0 on summary pages.
		// if $more == 1 then the entire post content gets populated into $content, so therefore we need to re-fetch content when $more == 0
		if ($more && !is_user_logged_in()) {
			global $more;
			$preserved_more = $more;
			$more = 0;
			// refresh the content with $more == 0 which will hide protected content
			$content = get_the_content($more_link_text='(more...)', $stripteaser=0, $more_file='');
			$more = $preserved_more;
			//$content = 'feed='.$content.'=endfeed ';
		} 
		
		if ($matches[2] == '') { 
			$content = preg_replace('/'.$matches[1].'/','Read the rest of this entry &raquo;',$content);
 		} else {
			// strip out the -memberlock tag since WP thinks that -memberlock is part of your customized link text
			$content = preg_replace('/>-memberlock/','>',$content);
		}
	}

	if ($memberlock_regchk == "loginfailed") {
		memberlock_inc_loginfailed();
		$content = '';
		return $content;
	}
	// if it is a page, is_single() will always return false, thus bypassing this entire function.  
	// pages are entirely controlled by WP's default settings
	if (is_single() || is_page()) { 
		// from function get_excerpt(): preg_match('/<!--more(.*?)?-->/'
		if (!is_user_logged_in() && $post_is_private) {
			if (is_object($post)) { $post->post_password = memberlock_generatePassword(); } // do this in order to protect comments from showing
			if ($memberlock_regchk) {
				switch($memberlock_regchk) {					
					case "loginfailed":
						memberlock_inc_loginfailed();
						$content = "";
						break;					
					case "success":
						memberlock_inc_regmessage($memberlock_themsg);
						$content .= memberlock_inc_login();
						break;
					default:
						memberlock_inc_regmessage($memberlock_themsg);
						$content = "";
						break;
				}		
			} else {
				$content .= memberlock_inc_login();
			}
		}
	}
	return $content;
}
function memberlock_securify_enclosure ($content) {
	global $memberlock_regchk, $memberlock_themsg, $memberlock_a, $post, $more;	
	if (preg_match('/<!--more(-memberlock(.*))-->/', $post->post_content,$matches) && !is_user_logged_in()) {
		$content = '';
	}
	return $content;
}


// login function
function memberlock_login() {
	global $wpdb,$table_prefix,$memberlock_regchk;
	
	$redirect_to = $_REQUEST['redirect_to'];
	if (!$redirect_to) {
		$redirect_to = $_SERVER['PHP_SELF'];
	}
	
	// we are reusing WP's own login scripts here.
	
	$user_login = $_POST['log'];
	$user_login = sanitize_user( $user_login );
	$user_pass  = $_POST['pwd'];
	
	do_action('wp_authenticate', array(&$user_login, &$user_pass));
	
	if ( $user_login && $user_pass ) {
		$user = new WP_User(0, $user_login);
		if ( wp_login($user_login, $user_pass, $using_cookie) ) {
			if ( !$using_cookie )
				wp_setcookie($user_login, $user_pass, false, '', '', $rememberme);
			
			do_action('wp_login', $user_login);
			
			wp_redirect($redirect_to);
			exit();
		} else {
			$memberlock_regchk = "loginfailed";
		}
			
	} else {
		//login failed
		$memberlock_regchk = "loginfailed";
	}
	
} // end of login function
// login function
function memberlock_wp_login($user_login) {
	global $wpdb;
	$user = new WP_User(0, $user_login);
	if ($user->ID) {
		$status = get_usermeta($user->ID, 'memberlock_status');
		if ($status == 'suspended') {
			memberlock_logout();
		}
	} else {
		memberlock_logout();
	}
} // end of login function


function memberlock_logout() {
	//take 'em to the blog home page
	$redirect_to = get_bloginfo('url');
	wp_logout();
	nocache_headers();	
	//die($redirect_to);	
	wp_redirect($redirect_to);
	exit();
}

/*****************************************************
END PRIMARY FUNCTIONS
*****************************************************/


/*****************************************************
UTILITY FUNCTIONS
*****************************************************/
function memberlock_create_formfield($name,$type,$value,$valtochk=null) {
	if ($type == "checkbox") {
		echo "<input name=\"$name\" type=\"$type\" id=\"$name\" value=\"$value\" ";
		memberlock_selected($value,$valtochk,$type);
		echo " />\n";
	} else {
		echo "<input name=\"$name\" type=\"$type\" id=\"$name\" value=\"$value\" />\n";
	}
}
function memberlock_chk_qstr() {
	$permalink = get_settings('permalink_structure');
	if (!$permalink) {
		// no fancy permalinks.  Append to ?=
		$return_url = get_settings('home') . "/?" . $_SERVER['QUERY_STRING'] . "&amp;";
	} else {
		// permalinks in use.  Add a ?
		$return_url = get_permalink() . "?";
	}
	return $return_url;
}
function memberlock_generatePassword() {	
	return substr( md5( uniqid( microtime() ) ), 0, 7);
}
/*****************************************************
END UTILITY FUNCTIONS
*****************************************************/

/*****************************************************
WIDGET FUNCTIONS
*****************************************************/
function widget_memberlockwidget_init()
{
	function widget_memberlockwidget($args)
	{
		extract($args);
		
		$options = get_option('widget_memberlockwidget');
		$title = $options['title'];
			
		echo $before_widget;
		
			// Widget Title
			if (!$title) {$title = "Login Status";}
			echo $before_title . $title . $after_title;
			
			// The Widget
			if (function_exists('memberlock')) { memberlock_inc_sidebar($widget);}

		echo $after_widget;
	}
	
	function widget_memberlockwidget_control()
	{
		// Get our options and see if we're handling a form submission.
		$options = get_option('widget_memberlockwidget');
		if ( !is_array($options) )
			$options = array('title'=>'', 'buttontext'=>__('Member Lock', 'widgets'));
		if ( $_POST['memberlockwidget-submit'] ) {

			// Remember to sanitize and format use input appropriately.
			$options['title'] = strip_tags(stripslashes($_POST['memberlockwidget-title']));
			update_option('widget_memberlockwidget', $options);
		}

		// Be sure you format your options to be valid HTML attributes.
		$title = htmlspecialchars($options['title'], ENT_QUOTES);
		
		// Here is our little form segment. Notice that we don't need a
		// complete form. This will be embedded into the existing form.
		echo '<p style="text-align:right;"><label for="memberlockwidget-title">' . __('Title:') . ' <input style="width: 200px;" id="memberlockwidget-title" name="memberlockwidget-title" type="text" value="'.$title.'" /></label></p>';
		echo '<input type="hidden" id="memberlockwidget-submit" name="memberlockwidget-submit" value="1" />';
	}

	register_sidebar_widget('Member Lock', 'widget_memberlockwidget');
	register_widget_control('Member Lock', 'widget_memberlockwidget_control');
}


/*****************************************************
END WIDGET FUNCTIONS
*****************************************************/


/*****************************************************
CUSTOMIZABLE OUTPUT FUNCTIONS
*****************************************************/


function memberlock_inc_login() { 
	/*
	This is the form and table for the login.
	You can redesign in any way you wish as long
	as you DO NOT change the form or input properties */
	
	global $memberlock_regchk;

	// we used to have the_permalink() as the form_action but it wasn't submitting properly if the URL didn't have a trailing slash /
	// For example:  http://localhost/wordpress didn't work, but http://localhost/wordpress/ did
	// This is because apache does not preserve the posted variables if it doesn't submit directly to the directory.
	// some WP plugins out there remove the trailing slash, so it would never submit properly if the directory actually exists 
	// (non-existing directories would probably work fine because it would catch the rewrite which would send it to some actual php file)
	// So now we just submit to wp-login.php so it will always work and then it just redirects to the previous page they were on.
	$form_action = get_option('siteurl')."/wp-login.php";
	$output = '';
	if($memberlock_regchk!="success"){	
		$memberlock_sales_html = get_option('memberlock_sales_html');
		$output .= '<p>'.$memberlock_sales_html.'</p>';	
	}
	$output .= '
		
	<form name="form1" method="post" action="'.$form_action.'">
	  <table width="400" border="0" cellspacing="0" cellpadding="4">
		<tr align="left"> 
		  <td colspan="2"><h2>Existing Users Login</h2></td>
		</tr>
		<tr> 
		  <td width="118" align="right">Username</td>
		  <td width="166"><input type="text" name="log" /></td>
		</tr>
		<tr> 
		  <td width="118" align="right">Password</td>
		  <td width="166"><input type="password" name="pwd" /></td>
		</tr>
		<tr> 
		  <td>&nbsp;</td>
		  <td>
		  	<input type="hidden" name="redirect_to" value="'.get_permalink().'" />
			<input type="hidden" name="a" value="login" />
			<input type="submit" name="Submit" value="login" />
		  </td>
		</tr>
	  </table>
	</form>	
';
	return $output;
}
function memberlock_inc_loginfailed() { 
	/* 
	failed login message.  
	you can customize this to fit your theme, etc.
	
	You may edit below this line */?>
	
	<div align="center">
		<h2>Login Failed!</h2>
		<p>You entered an invalid username or password.</p>
		<p><a href="<?php echo $_SERVER['REQUEST_URI'];?>">Click here to continue.</a></p>
	</div>
	
	<?php  // end edits for function memberlock_inc_loginfailed()
}
function memberlock_inc_sidebar() {
	/*
	This function determines if the user is logged in
	and displays either a login form, or the user's 
	login status. Typically used for a sidebar.		
	You can call this directly, or with the widget
	*/
	global $user_login;
	$url = get_bloginfo('url');
	$logout = $url."/?a=logout";
	
	//this returns us to the right place
	if(is_home()) {
		$post_to = $_SERVER['PHP_SELF'];
	}else{
		$post_to = get_permalink();
	}
	// we used to have the_permalink() as the form_action but it wasn't submitting properly if the URL didn't have a trailing slash /
	// For example:  http://localhost/wordpress didn't work, but http://localhost/wordpress/ did
	// This is because apache does not preserve the posted variables if it doesn't submit directly to the directory.
	// some WP plugins out there remove the trailing slash, so it would never submit properly if the directory actually exists 
	// (non-existing directories would probably work fine because it would catch the rewrite which would send it to some actual php file)
	// So now we just submit to wp-login.php so it will always work and then it just redirects to the previous page they were on.
	$form_action = get_option('siteurl')."/wp-login.php";
		
	if (!is_user_logged_in()){
	/*
	This is the login form.
	You may edit below this line, but do not
	change the <?php ?> tags or their contents */?>
	<ul>
		<p>You are not currently logged in.<br />
			<form name="form" method="post" action="<?php echo $form_action; ?>">
			Username<br />
			<input type="text" name="log" style="font:10px verdana,sans-serif;" /><br />
			Password<br />
			<input type="password" name="pwd" style="font:10px verdana,sans-serif;" /><br />
			<input type="hidden" name="redirect_to" value="<?php echo $post_to; ?>" />
			<input type="hidden" name="a" value="login" />
			<input type="submit" name="Submit" value="login" style="font:10px verdana,sans-serif;" />
			</form>
		</p>
	</ul>
	<?php } else { 
		global $user_login;
		$logout = get_bloginfo('url')."/?a=logout";
	
		$str = "<p>".__('You are logged in as')." $user_login </p>";

		$link = get_option('memberlock_billing_link');
		$str .= "<ul>\n";
		if ($link != '') {
			$str .=	"<li><a href=\"".$link."\">Edit Billing Information</a></li>\n";
		}
		$str .=	"<li><a href=\"".$logout."\">Click Here to Logout</a></li>\n";
		$str .= "</ul>";
	 } 
	 print $str;
}
function memberlock_inc_regmessage($themsg='') { 
		?>
	<div class="memberlock_msg" align="center">
		<p>&nbsp;</p>
		<p><b><?php echo $themsg; ?></b></p>
		<p>&nbsp;</p>
	</div>
	<?php 
} 
function memberlock_GetChildren($vals, &$i) 
{ 
  $children = array();     // Contains node data
  
  /* Node has CDATA before it's children */
  if (isset($vals[$i]['value'])) 
    $children['VALUE'] = $vals[$i]['value']; 
  
  /* Loop through children */
  while (++$i < count($vals))
  { 
    switch ($vals[$i]['type']) 
    { 
      /* Node has CDATA after one of it's children 
        (Add to cdata found before if this is the case) */
      case 'cdata': 
        if (isset($children['VALUE']))
          $children['VALUE'] .= $vals[$i]['value']; 
        else
          $children['VALUE'] = $vals[$i]['value']; 
        break;
      /* At end of current branch */ 
      case 'complete': 
        if (isset($vals[$i]['attributes'])) {
          $children[$vals[$i]['tag']][]['ATTRIBUTES'] = $vals[$i]['attributes'];
          $index = count($children[$vals[$i]['tag']])-1;

          if (isset($vals[$i]['value'])) 
            $children[$vals[$i]['tag']][$index]['VALUE'] = $vals[$i]['value']; 
          else
            $children[$vals[$i]['tag']][$index]['VALUE'] = ''; 
        } else {
          if (isset($vals[$i]['value'])) 
            $children[$vals[$i]['tag']][]['VALUE'] = $vals[$i]['value']; 
          else
            $children[$vals[$i]['tag']][]['VALUE'] = ''; 
        }
        break; 
      /* Node has more children */
      case 'open': 
        if (isset($vals[$i]['attributes'])) {
          $children[$vals[$i]['tag']][]['ATTRIBUTES'] = $vals[$i]['attributes'];
          $index = count($children[$vals[$i]['tag']])-1;
          $children[$vals[$i]['tag']][$index] = array_merge($children[$vals[$i]['tag']][$index],memberlock_GetChildren($vals, $i));
        } else {
          $children[$vals[$i]['tag']][] = memberlock_GetChildren($vals, $i);
        }
        break; 
      /* End of node, return collected data */
      case 'close': 
        return $children; 
    } 
  } 
} 
function memberlock_GetXMLTree($data) 
{ 
  $parser = xml_parser_create('UTF-8');
  xml_parser_set_option($parser, XML_OPTION_SKIP_WHITE, 1); 
  xml_parse_into_struct($parser, $data, $vals, $index); 
  xml_parser_free($parser); 

  $tree = array(); 
  $i = 0; 
  
  if (isset($vals[$i]['attributes'])) {
    $tree[$vals[$i]['tag']][]['ATTRIBUTES'] = $vals[$i]['attributes']; 
    $index = count($tree[$vals[$i]['tag']])-1;
    $children = memberlock_GetChildren($vals, $i);
    if (!is_array($children)) { $children = array(); }
    if (!is_array($tree[$vals[$i]['tag']][$index])) { $tree[$vals[$i]['tag']][$index] = array(); }
    $tree[$vals[$i]['tag']][$index] =  array_merge($tree[$vals[$i]['tag']][$index], $children);
  }
  else
    $tree[$vals[$i]['tag']][] = memberlock_GetChildren($vals, $i); 
  
  return $tree; 
} 
?>